//------------------------------------------------------------------------------
//
// ILib.  Written by Punk Jozsef.
//
// Copyright 2007 Intuitive Computers.  All rights reserved.
//
// Library definitions for Intuitive Media Studio.
//
//------------------------------------------------------------------------------

//------------------------------------------------------------------------------
// Constants
//------------------------------------------------------------------------------

// Control Devices
enum CDevice {
	CKeyboard = 0,
	CMouse = 1,
	CPad0 = 2,
	CPad1 = 3
};

enum CControl {
	CPadSelect = 0,
	CPadStart = 1,
	CPadUp = 2,
	CPadRight = 3,
	CPadDown = 4,
	CPadLeft = 5,
	CPadTriangle = 6,
	CPadCircle = 7,
	CPadX = 8,
	CPadSquare = 9,
	CPadL1 = 10,
	CPadR1 = 11,
	CPadL2 = 12,
	CPadR2 = 13
};

//------------------------------------------------------------------------------
// Types
//------------------------------------------------------------------------------

struct Vector3 {
	float					x, y, z;
};

struct Matrix {
	float					a11, a12, a13, a14;
	float					a21, a22, a23, a24;
	float					a31, a32, a33, a34;
	float					a41, a42, a43, a44;
};

//------------------------------------------------------------------------------
// Functions
//------------------------------------------------------------------------------

void	 Vector3Null (Vector3 v) syscall (0, 15);
void	 Vector3Set (Vector3 v, float x, float y, float z) syscall (0, 16);
void	 Vector3Add (Vector3 v, Vector3 a, Vector3 b) syscall (0, 17);
void	 Vector3Sub (Vector3 v, Vector3 a, Vector3 b) syscall (0, 18);
void	 Vector3Scale (Vector3 v, Vector3 a, float s) syscall (0, 19);
void	 Vector3Normalize (Vector3 v, Vector3 a) syscall (0, 20);
void	 Vector3Lerp (Vector3 v, Vector3 a, Vector3 b, float s) syscall (0, 21);
void	 Vector3Cross (Vector3 v, Vector3 a, Vector3 b) syscall (0, 22);
float	 Vector3Dot (Vector3 a, Vector3 b) syscall (0, 23);
float	 Vector3Length (Vector3 a) syscall (0, 24);
float	 Vector3LengthSq (Vector3 a) syscall (0, 25);

void	 MatrixIdentity (Matrix m) syscall (0, 8);
void	 MatrixScaling (Matrix m, float x, float y, float z) syscall (0, 9);
void	 MatrixRotationX (Matrix m, float x) syscall (0, 10);
void	 MatrixRotationY (Matrix m, float y) syscall (0, 11);
void	 MatrixRotationZ (Matrix m, float z) syscall (0, 12);
void	 MatrixTranslation (Matrix m, float x, float y, float z) syscall (0, 13);
void	 MatrixMultiply (Matrix m, Matrix a, Matrix b) syscall (0, 14);

int		 FrameStart () syscall (0, 0);
int		 FrameEnd () syscall (0, 1);
int		 FrameClear () syscall (0, 2);

int		 System () syscall (0, 3);

void	 SpriteDraw (int x, int y, int sprite) syscall (0, 4);

float	 ControlValue (CDevice device, CControl control) syscall (0, 5);

void	 CameraSet (float tx, float ty, float tz, float dir, float elev, float dist, float fov) syscall (0, 6);

void	 ModelDraw (int model, Matrix local) syscall (0, 7);

int		 SoundPlay (int sound) syscall (0, 100);

void	 TerrainDraw (int terrain) syscall (0, 101);

void	 DisplaySize (int w, int h) syscall (0, 200);

void	 ImageDraw (int x, int y, int image) syscall (0, 201);

